@@ -3,11 +3,13 @@
 """
 import json
 
+
 class BotAPIResponse:
     """
     Parses the right object for the response
     """
-    def __init__(self,raw_json,expected_object = None):
+
+    def __init__(self, raw_json, expected_object=None):
         """Creates a BotAPIResponse object and sets variables for errors
 
         This object can handle errors and is passed as second variable by functions
@@ -27,9 +29,17 @@ class BotAPIResponse:
         """Error code given by botAPI, if there is no error it is set to `None`"""
         self.description = None
         """Error description given by botAPI, if there is no error it is set to `None`"""
-        if (self.decoded["ok"] == False) and "result" in self.decoded:
-            self.error_code = self.decoded["error_code"]
-            self.description = self.decoded["description"]
+        self.connection_error = None
+        """bool, True if there was a connection error, False if not"""
+        if (not self.decoded["ok"]) and "result" in self.decoded:
+            if "error_code" in self.decoded:
+                self.error_code = self.decoded["error_code"]
+            if "description" in self.decoded:
+                self.description = self.decoded["description"]
+            if "connection_error" in self.decoded:
+                self.connection_error = self.decoded["connection_error"]
+            else:
+                self.connection_error = False
         else:
             self.expected_object = expected_object
 
@@ -41,14 +51,16 @@ class BotAPIResponse:
         - `None`: if there was an error
         - Object specified in the init: if the request was a success
         """
-        if "result" in self.decoded and (self.expected_object == None or self.expected_object.__module__ != "silbot.types" or (type(self.decoded["result"]) != dict and type(self.decoded["result"]) != list)):
+        if "result" in self.decoded and (
+                self.expected_object is None or self.expected_object.__module__ != "silbot.types" or (
+                type(self.decoded["result"]) != dict and type(self.decoded["result"]) != list)):
             return self.decoded["result"]
         if self.decoded["ok"]:
             return self.expected_object(self.decoded["result"])
         else:
             return None
 
-    def setObject(self,func):
+    def setObject(self, func):
         """Parse the response as a given object, returns None if there is an error
 
         **Args**:
@@ -62,4 +74,4 @@ class BotAPIResponse:
         if "result" in self.decoded:
             return func(self.decoded["result"])
         else:
-            return None
\ No newline at end of file
+            return None
