@@ -2,17 +2,17 @@
 ## This module's purpose is to handle botApi updates with multithreading
 """
 
-import json
 from threading import Thread
-from silbot import botapi
-from silbot import types
+
+from silbot import botapi, types
 
 
 class update(Thread):
     """
     Elaborates the update in another thread
     """
-    def __init__(self,update,bot: botapi.botApi, function):
+
+    def __init__(self, update, bot: botapi.BotApi, function):
         """
         Sets some var
 
@@ -22,17 +22,13 @@ class update(Thread):
         - function (`function`): function to call to elaborate the update
         """
         self.update = update
+        self.parsed = types.Update(self.update)
         self.bot = bot
         self.function = function
         Thread.__init__(self)
+
     def run(self):
         """
         This is callen when the thread starts, parses the update and calls the given function
         """
-        self.parsed = types.Update(self.update)
-        self.function(self.parsed,self.bot)
-
-
-
-
-
+        self.function(self.parsed, self.bot)
